pub enum CoverageState {
None,
Partial,
Full,
}Expand description
Captured-union coverage state for an object.
Variants
None
The object has zero captured area, or a point is outside the union.
Partial
Some but not all object area is captured.
Full
All object area is captured, or a point is inside/on the boundary.