pub struct RotationSearch { /* private fields */ }Expand description
Caller-controlled numerical search domain for coverage rotation intervals.
sample_step determines the narrowest interval the grid can discover.
Each detected transition is bisected to tolerance.
Implementations
Sourceimpl RotationSearch
impl RotationSearch
Sourcepub fn new(
minimum: Angle,
maximum: Angle,
sample_step: Angle,
tolerance: Angle,
) -> Result<Self>
pub fn new( minimum: Angle, maximum: Angle, sample_step: Angle, tolerance: Angle, ) -> Result<Self>
Construct a finite increasing search domain and positive resolutions.
Errors
Returns Error::InvalidRotationSearch when the domain or resolutions
are invalid or require more than one million samples.
Sourcepub fn sample_step(self) -> Angle
pub fn sample_step(self) -> Angle
Grid spacing used to discover intervals.