pub struct Matcher<T> { /* private fields */ }Expand description
Implementations
Sourceimpl<T: SkyObject> Matcher<T>
impl<T: SkyObject> Matcher<T>
Sourcepub fn from_objects(objects: Vec<T>) -> Self
pub fn from_objects(objects: Vec<T>) -> Self
Build an index from a set of objects (original order is preserved for
tie-breaking and objects).
Sourcepub fn query(&self, pointing: Equatorial, c: Constraint) -> Vec<Match<'_, T>>
pub fn query(&self, pointing: Equatorial, c: Constraint) -> Vec<Match<'_, T>>
Query the index for a pointing under a constraint.
Sourcepub fn is_framed<'a>(
&self,
pointing: Equatorial,
object: &'a T,
m: Membership,
) -> Match<'a, T>
pub fn is_framed<'a>( &self, pointing: Equatorial, object: &'a T, m: Membership, ) -> Match<'a, T>
Evaluate a single stored-or-external object against a frame (see is_framed).